@@ -1,5 +1,5 @@
 package DBIx::Lite::Row;
-$DBIx::Lite::Row::VERSION = '0.19';
+$DBIx::Lite::Row::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -8,54 +8,43 @@ use Clone qw(clone);
 use vars qw($AUTOLOAD);
 $Carp::Internal{$_}++ for __PACKAGE__;
 
-sub _new {
-    my $class = shift;
-    my (%params) = @_;
+sub _pk {
+    my $self = shift;
+    my $selfs = $self->__dbix_lite_row_storage;
     
-    my $self = {};
+    my @keys = $selfs->{table}->pk
+        or croak "No primary key defined for table " . $selfs->{table}{name};
     
-    for (qw(dbix_lite table data)) {
-        $self->{$_} = delete $params{$_} or croak "$_ argument needed";
-    }
+    grep(!exists $selfs->{data}{$_}, @keys)
+        and croak "No primary key data retrieved for table " . $selfs->{table}{name};
     
-    !%params
-        or croak "Unknown options: " . join(', ', keys %params);
-    
-    bless $self, $class;
-    $self;
+    return { map +($_ => $selfs->{data}{$_}), @keys };
 }
 
-sub pk {
-    my $self = shift;
-    
-    my @keys = $self->{table}->pk
-        or croak "No primary key defined for table " . $self->{table}{name};
-    
-    grep(!exists $self->{data}{$_}, @keys)
-        and croak "No primary key data retrieved for table " . $self->{table}{name};
-    
-    return { map +($_ => $self->{data}{$_}), @keys };
-}
+sub __dbix_lite_row_storage { $_[0] }
 
 sub hashref {
     my $self = shift;
+    my $selfs = $self->__dbix_lite_row_storage;
     
-    return clone $self->{data};
+    return clone $selfs->{data};
 }
 
 sub update {
     my $self = shift;
     my $update_cols = shift or croak "update() requires a hashref";
+    my $selfs = $self->__dbix_lite_row_storage;
     
-    $self->{dbix_lite}->table($self->{table}{name})->search($self->pk)->update($update_cols);
-    $self->{data}{$_} = $update_cols->{$_} for keys %$update_cols;
+    $selfs->{dbix_lite}->table($selfs->{table}{name})->search($self->_pk)->update($update_cols);
+    $selfs->{data}{$_} = $update_cols->{$_} for keys %$update_cols;
     $self;
 }
 
 sub delete {
     my $self = shift;
+    my $selfs = $self->__dbix_lite_row_storage;
     
-    $self->{dbix_lite}->table($self->{table}{name})->search($self->pk)->delete;
+    $selfs->{dbix_lite}->table($selfs->{table}{name})->search($self->_pk)->delete;
     undef $self;
 }
 
@@ -63,27 +52,29 @@ sub insert_related {
     my $self = shift;
     my ($rel_name, $insert_cols) = @_;
     $rel_name or croak "insert_related() requires a table name";
+    my $selfs = $self->__dbix_lite_row_storage;
     
     my ($table_name, $my_key, $their_key) = $self->_relationship($rel_name)
-        or croak "No $rel_name relationship defined for " . $self->{table}{name};
+        or croak "No $rel_name relationship defined for " . $selfs->{table}{name};
     
-    return $self->{dbix_lite}
+    return $selfs->{dbix_lite}
         ->table($table_name)
-        ->insert({ $their_key => $self->{data}{$my_key}, %$insert_cols });
+        ->insert({ $their_key => $selfs->{data}{$my_key}, %$insert_cols });
 }
 
 sub _relationship {
     my $self = shift;
     my ($rel_name) = @_;
+    my $selfs = $self->__dbix_lite_row_storage;
     
-    my ($rel_type) = grep $self->{table}{$_}{$rel_name}, qw(has_one has_many)
+    my ($rel_type) = grep $selfs->{table}{$_}{$rel_name}, qw(has_one has_many)
         or return ();
     
-    my $rel = $self->{table}{$rel_type}{$rel_name};
+    my $rel = $selfs->{table}{$rel_type}{$rel_name};
     my ($table_name, $my_key, $their_key) = ($rel->[0], %{ $rel->[1] });
     
-    exists $self->{data}{$my_key}
-        or croak "No $my_key key retrieved from " . $self->{table}{name};
+    exists $selfs->{data}{$my_key}
+        or croak "No $my_key key retrieved from " . $selfs->{table}{name};
     
     return ($table_name, $my_key, $their_key, $rel_type);
 }
@@ -91,28 +82,31 @@ sub _relationship {
 sub get {
     my $self = shift;
     my $key = shift or croak "get() requires a column name";
-    return $self->{data}{$key};
+    my $selfs = $self->__dbix_lite_row_storage;
+    
+    return $selfs->{data}{$key};
 }
 
 sub AUTOLOAD {
     my $self = shift or return undef;
+    my $selfs = $self->__dbix_lite_row_storage;
     
     # Get the called method name and trim off the namespace
     (my $method = $AUTOLOAD) =~ s/.*:://;
 	
-    if (exists $self->{data}{$method}) {
-        return $self->{data}{$method};
+    if (exists $selfs->{data}{$method}) {
+        return $selfs->{data}{$method};
     }
     
     if (my ($table_name, $my_key, $their_key, $rel_type) = $self->_relationship($method)) {
-        my $rs = $self->{dbix_lite}
+        my $rs = $selfs->{dbix_lite}
             ->table($table_name)
-            ->search({ "me.$their_key" => $self->{data}{$my_key} });
+            ->search({ "me.$their_key" => $selfs->{data}{$my_key} });
         return $rel_type eq 'has_many' ? $rs : $rs->single;
     }
     
     croak sprintf "No %s method is provided by this %s (%s) object",
-        $method, ref($self), $self->{table}{name};
+        $method, ref($self), $selfs->{table}{name};
 }
 
 sub DESTROY {}
@@ -131,12 +125,12 @@ DBIx::Lite::Row
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 OVERVIEW
 
 This class is not supposed to be instantiated manually. You usually get your 
-first Result objects by calling some retrieval methods on a L<DBIx::Lite::ResultSet>
+first Result objects by calling one of retrieval methods on a L<DBIx::Lite::ResultSet>
 object.
 
 Accessor methods will be provided automatically for all retrieved columns and for 
@@ -144,6 +138,7 @@ related tables (see docs for L<DBIx::Lite::Schema>).
 
     my $book = $dbix->table('books')->find({ id => 10 });
     print $book->title;
+    print $book->author->name;
 
 =head2 hashref
 
@@ -178,7 +173,7 @@ object.
     $dbix->schema->one_to_many('authors.id' => 'books.author_id');
     my $book = $author->insert_related('books', { title => 'Camel Tales' });
 
-=for Pod::Coverage get pk
+=for Pod::Coverage get _pk
 
 =head1 AUTHOR
 
